==> nextcloud-25.0.8.tgz: nextcloud/apps/theming/l10n/ko.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "입력한 이름이 너무 김",
    "The given web address is too long" : "입력한 웹 주소가 너무 김",
    "The given legal notice address is too long" : "입력한 법적 고지가 너무 김",
    "The given privacy policy address is too long" : "입력한 개인 정보 취급 방침 주소가 너무 김",
    "The given slogan is too long" : "입력한 슬로건이 너무 김",
    "The given color is invalid" : "입력한 색상이 잘못됨",
    "Saved" : "저장됨",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded" : "업로드한 파일 없음",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "사용자 정의 테마를 사용하고 있습니다. 테마 앱에서 해당 설정을 덮어쓸 수 있습니다.",
    "Theming" : "테마",
    "Appearance and accessibility" : "외형과 접근성",
    "Dark theme with high contrast mode" : "고대비 모드의 어두운 테마",
    "Dark theme" : "어두운 테마",
    "Enable dark theme" : "어두운 테마 활성화",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "어두운 테마는 전체적인 광량을 줄여 사용자의 눈을 편안하게 합니다.",
    "System default theme" : "시스템 기본 테마",
    "Dyslexia font" : "난독증용 글꼴",
    "Enable dyslexia font" : "난독증용 글꼴 활성화",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic은 난독증 때문에 읽기에 문제가 있는 사람들을 위해 디자인된 자유 글꼴입니다.",
    "High contrast mode" : "고대비 모드",
    "Enable high contrast mode" : "고대비 모드 활성화",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
    "Light theme" : "밝은 테마",
    "Enable the default light theme" : "기본 밝은 테마 활성화",
    "Legal notice" : "법적 고지",
    "Privacy policy" : "개인 정보 취급 방침",
    "Adjust the Nextcloud theme" : "Nextcloud 테마 사용자 정의",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
    "Advanced options" : "고급 설정",
    "Name" : "이름",
    "Web link" : "웹 링크",
    "a safe home for all your data" : "내 모든 데이터 안전 저장소",
    "Slogan" : "슬로건",
    "Color" : "색",
    "Logo" : "로고",
    "Upload new logo" : "새 로고 업로드",
    "Legal notice link" : "법적 고지 링크",
    "Privacy policy link" : "개인 정보 취급 방침 링크",
    "Header logo" : "머리글 로고",
    "Upload new header logo" : "새 머리글 로고 업로드",
    "Favicon" : "파비콘",
    "Upload new favicon" : "새 파비콘 업로드",
    "User settings" : "사용자 설정",
    "Keyboard shortcuts" : "키보드 단축키",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "특정 상황에서, 키보드 단축키는 접근성 도구의 동작과 간섭을 일으킬 수 있습니다. 간섭 방지와 접근성 도구의 정확한 동작을 위해, 이곳에서 모든 키보드 단축키를 비활성화할 수 있습니다. 이는 앱에서 사용할 수 있는 모든 단축키 또한 비활성화합니다.",
    "Disable all keyboard shortcuts" : "모든 키보드 단축키 비활성화",
    "Background" : "배경",
    "Set a custom background" : "나만의 배경화면 설정",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "보편적 접근성은 매우 중요합니다. 저희는 웹 표준을 준수하며, 마우스 혹은 스크린리더와 같은 보조 소프트웨어 없이도 정상적인 사용이 가능한지에 대해 확인하고 있습니다. 또한, {guidelines}웹 컨텐츠 접근성 가이드라인{linkend} 2.1을 AA 수준 및 AAA 수준의 고대비 테마에서 준수하기 위해 노력하고 있습니다. ",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "사용 중 문제가 발생했을 경우, {issuetracker}이슈 트래커{linkend}에 보고해주시기 바랍니다. 또한 디자인 부분에 참여하고 싶다면, {designteam}저희 디자인 팀{linkend}과 함께해주세요!",
    "Change color" : "색깔 바꾸기",
    "Theme selection is enforced" : "테마가 강제로 선택됨",
    "Reset to default" : "기본값으로 초기화",
    "Upload" : "업로드",
    "Remove background image" : "배경 그림 삭제",
    "Loading preview…" : "미리 보기 불러오는 중…",
    "Admin" : "관리자",
    "Name cannot be empty" : "이름이 비어 있을 수 없음",
    "Pick from Files" : "파일로부터 선택",
    "Plain background" : "일반 배경",
    "Insert from {productName}" : "{productName}로부터 삽입",
    "Open documentation" : "문서 열기",
    "https://…" : "https://…",
    "Upload new login background" : "새 로그인 배경 업로드",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "업로드한 로고와 색으로부터 자동으로 파비콘을 생성하려면 PHP Imagemagick 확장 기능 및 SVG 형식 그림 지원을 설치하십시오."
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.12.tgz: nextcloud/apps/theming/l10n/ko.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "입력한 이름이 너무 김",
    "The given web address is too long" : "입력한 웹 주소가 너무 김",
    "The given legal notice address is too long" : "입력한 법적 고지가 너무 김",
    "The given privacy policy address is too long" : "입력한 개인 정보 취급 방침 주소가 너무 김",
    "The given slogan is too long" : "입력한 슬로건이 너무 김",
    "The given color is invalid" : "입력한 색상이 잘못됨",
    "Saved" : "저장됨",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded" : "업로드한 파일 없음",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "사용자 정의 테마를 사용하고 있습니다. 테마 앱에서 해당 설정을 덮어쓸 수 있습니다.",
    "Theming" : "테마",
    "Appearance and accessibility" : "외형과 접근성",
    "Dark theme with high contrast mode" : "고대비 모드의 어두운 테마",
    "Dark theme" : "어두운 테마",
    "Enable dark theme" : "어두운 테마 활성화",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "어두운 테마는 전체적인 광량을 줄여 사용자의 눈을 편안하게 합니다.",
    "System default theme" : "시스템 기본 테마",
    "Dyslexia font" : "난독증용 글꼴",
    "Enable dyslexia font" : "난독증용 글꼴 활성화",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic은 난독증 때문에 읽기에 문제가 있는 사람들을 위해 디자인된 자유 글꼴입니다.",
    "High contrast mode" : "고대비 모드",
    "Enable high contrast mode" : "고대비 모드 활성화",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
    "Light theme" : "밝은 테마",
    "Enable the default light theme" : "기본 밝은 테마 활성화",
    "Legal notice" : "법적 고지",
    "Privacy policy" : "개인 정보 취급 방침",
    "Adjust the Nextcloud theme" : "Nextcloud 테마 사용자 정의",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
    "Advanced options" : "고급 설정",
    "Name" : "이름",
    "Web link" : "웹 링크",
    "a safe home for all your data" : "내 모든 데이터 안전 저장소",
    "Slogan" : "슬로건",
    "Color" : "색",
    "Logo" : "로고",
    "Upload new logo" : "새 로고 업로드",
    "Legal notice link" : "법적 고지 링크",
    "Privacy policy link" : "개인 정보 취급 방침 링크",
    "Header logo" : "머리글 로고",
    "Upload new header logo" : "새 머리글 로고 업로드",
    "Favicon" : "파비콘",
    "Upload new favicon" : "새 파비콘 업로드",
    "User settings" : "사용자 설정",
    "Background" : "배경",
    "Set a custom background" : "나만의 배경화면 설정",
    "Keyboard shortcuts" : "키보드 단축키",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "특정 상황에서, 키보드 단축키는 접근성 도구의 동작과 간섭을 일으킬 수 있습니다. 간섭 방지와 접근성 도구의 정확한 동작을 위해, 이곳에서 모든 키보드 단축키를 비활성화할 수 있습니다. 이는 앱에서 사용할 수 있는 모든 단축키 또한 비활성화합니다.",
    "Disable all keyboard shortcuts" : "모든 키보드 단축키 비활성화",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "보편적 접근성은 매우 중요합니다. 저희는 웹 표준을 준수하며, 마우스 혹은 스크린리더와 같은 보조 소프트웨어 없이도 정상적인 사용이 가능한지에 대해 확인하고 있습니다. 또한, {guidelines}웹 콘텐츠 접근성 가이드라인{linkend} 2.1을 AA 수준 및 AAA 수준의 고대비 테마에서 준수하기 위해 노력하고 있습니다. ",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "사용 중 문제가 발생했을 경우, {issuetracker}이슈 트래커{linkend}에 보고해주시기 바랍니다. 또한 디자인 부분에 참여하고 싶다면, {designteam}저희 디자인 팀{linkend}과 함께해주세요!",
    "Change color" : "색깔 바꾸기",
    "Theme selection is enforced" : "테마가 강제로 선택됨",
    "Reset to default" : "기본값으로 초기화",
    "Upload" : "업로드",
    "Remove background image" : "배경 그림 삭제",
    "Loading preview…" : "미리 보기 불러오는 중…",
    "Admin" : "관리자",
    "Name cannot be empty" : "이름이 비어 있을 수 없음",
    "Pick from Files" : "파일로부터 선택",
    "Plain background" : "일반 배경",
    "Insert from {productName}" : "{productName}로부터 삽입",
    "Open documentation" : "문서 열기",
    "https://…" : "https://…",
    "Upload new login background" : "새 로그인 배경 업로드",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "업로드한 로고와 색으로부터 자동으로 파비콘을 생성하려면 PHP Imagemagick 확장 기능 및 SVG 형식 그림 지원을 설치하십시오."
},
"nplurals=1; plural=0;");
